@@ -1,8 +1,14 @@
 package Mason::t::Interp;
+BEGIN {
+  $Mason::t::Interp::VERSION = '2.10';
+}
 use Test::Class::Most parent => 'Mason::Test::Class';
 use Capture::Tiny qw(capture);
 
-{ package MyInterp; use Moose; extends 'Mason::Interp' }
+{ package MyInterp;
+BEGIN {
+  $MyInterp::VERSION = '2.10';
+} use Moose; extends 'Mason::Interp' }
 
 sub test_base_interp_class : Tests {
     my $self = shift;
